@@ -1,4 +1,4 @@
-from typing import Any, List, Iterable, Callable, Type, NoReturn
+from typing import Any, Iterable, Type
 
 
 class TableEngine:
@@ -14,8 +14,12 @@ class TableEngine:
             sql += f'({", ".join(self.args)})'
         return sql
 
-    def preprocess_select_request(self, select: 'Select') -> NoReturn:
+    def preprocess_select_request(self, select: 'Select') -> None:
         ...
 
-    def apply(self, table: Type['Table']) -> NoReturn:
+    def apply(self, table: Type['Table']) -> None:
         ...
+
+    @staticmethod
+    def construct_from_sql(table: Type['Table']) -> str:
+        return table.get_name()
